#! /bin/bash

PSQL="/opt/passlogic/pgsql/bin/psql -p 5439"
LOCKDIR="/opt/passlogic/pgsql/backuplock"
BACKUP_LABEL="/opt/passlogic/pgsql/data/backup_label"

MASTER_BASEDIR=$1
RECOVERY_HOST=$2
RECOVERY_BASEDIR=$3

cat /etc/redhat-release | grep "release 7"
if [ $? -eq 0 ]; then
OS_EL=7
else
OS_EL=6
fi

PGSQL_LOG="/opt/passlogic/pgsql/data/serverlog"

echo `date +'%Y/%m/%d %H:%M:%S'` "START - recovery_1st_stage.sh"                >> $PGSQL_LOG
echo `date +'%Y/%m/%d %H:%M:%S'` " MASTER_BASEDIR = $MASTER_BASEDIR"            >> $PGSQL_LOG
echo `date +'%Y/%m/%d %H:%M:%S'` " RECOVERY_HOST = $RECOVERY_HOST"              >> $PGSQL_LOG
echo `date +'%Y/%m/%d %H:%M:%S'` " RECOVERY_BASEDIR = $RECOVERY_BASEDIR"        >> $PGSQL_LOG

COUNT=0
while [ 1 ];
 do
  mkdir $LOCKDIR
  if [ $? -ne 0 ]; then
   let COUNT++
   sleep 3
  else
   break
  fi
  if [ $COUNT -gt 100 ]; then # 5 minutes
    COUNT=0
    if [ -f $BACKUP_LABEL ]; then
     continue;
    fi
    rmdir $LOCKDIR
  fi
 done


if [ $OS_EL -eq 7 ]; then
ssh -T $RECOVERY_HOST 'sh /opt/passlogic/apps/tools/pgsql-stop.sh'
else
ssh -T $RECOVERY_HOST /opt/passlogic/pgsql/bin/pg_ctl stop -D $RECOVERY_BASEDIR/ -m f
fi

sleep 5

# ベースバックアップの開始
$PSQL -c "SELECT pg_start_backup('pgpool-recovery')" template1

# リカバリ先用のrecovry.confファイル生成
echo "restore_command = 'cp $RECOVERY_BASEDIR/../archives/%f %p'" > $MASTER_BASEDIR/recovery.conf

# データベースクラスタ=ベースバックアップをリカバリ先に転送
rsync -az --delete -e ssh  \
      --exclude serverlog  \
      --exclude pg_xlog    \
      $MASTER_BASEDIR/ $RECOVERY_HOST:$RECOVERY_BASEDIR/

ssh -T $RECOVERY_HOST rm -f  $RECOVERY_BASEDIR/postmaster.pid
ssh -T $RECOVERY_HOST rm -rf  $RECOVERY_BASEDIR/pg_xlog
ssh -T $RECOVERY_HOST mkdir -p $RECOVERY_BASEDIR/pg_xlog/archive_status
ssh -T $RECOVERY_HOST rm -f  $RECOVERY_BASEDIR/backup_label.old
ssh -T $RECOVERY_HOST rm -f  $RECOVERY_BASEDIR/recovery.done

# リカバリ先に転送したので、不要になったrecovery.confを削除
rm -f $MASTER_BASEDIR/recovery.conf

# ベースバックアップの終了
$PSQL -c "SELECT pg_stop_backup()" template1

echo `date +'%Y/%m/%d %H:%M:%S'` "DONE - recovery_1st_stage.sh"                >> $PGSQL_LOG
